@@ -2,18 +2,18 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-FileCopyrightText: 2024-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 from errno import EEXIST, ENOENT
-from os import O_CREAT, O_WRONLY, _exit, fork, getpid, open, wait
+from os import O_CREAT, O_WRONLY, _exit, fork, getpid, open, wait  # noqa: A004
 
 import pytest
 
 import univention.updater.locking as L
 
 
-@pytest.fixture()
+@pytest.fixture
 def lock(tmpdir, monkeypatch):
     """Mock locking file"""
     lock = tmpdir / "lock"
@@ -164,7 +164,7 @@ def test_error_taken(lock):
         lock.mkdir()
 
 
-@pytest.fixture()
+@pytest.fixture
 def apt_lock(tmpdir, monkeypatch):
     """Mock APT locking file"""
     lock = tmpdir / "lock"
